---
title: 정기결제 카드 유효성 검증 방법
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 정기결제
seo:
  title: 정기결제 카드 유효성 검증 방법
  description: >-
    정기결제 카드 유효성 검증 방법에 대해 안내드립니다. 존재하는 카드를 체크하는 방법, 카드의 결제 가능 여부, 카드번호가 15자리일
    경우, 카드 실 소유주 체크방법 등을 포함하고 있습니다.
  keywords:
    - 정기결제
tags:
  - 공통
  - 정기결제
pgCompanies:
  - 공통
searchTags:
  - 정기결제유효성
  - 유효성검증
  - 카드유효성
  - 유효성
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="PG사별/카드사별로 카드 유효성을 검증하는 기준이 모두 상이할 수 있습니다.
(ex : 카드번호 + 유효기간만 확인, 카드번호 앞 6자리 + 유효기간만 확인 등)" title="" />

### **존재하는 카드인지만 체크하는 방법**

- 비인증 결제 <Highlight text="(POST /subscribe/custormers/{customer_uid})" /> 시도 시 카드 등록이 정상적으로 이뤄지면 유효성 체크가 된 것입니다.
- 다만, 이 경우 등록하는 시점에 분실정지, 잔액부족 카드인 경우 결제 승인은 불가능한 상태이지만 \
  카드번호+유효기간+생년월일+비밀번호(앞 2자리) 4가지 정보는 실제 존재하는 카드가 맞으므로 정상적으로 등록 처리가 되는 점을 참고해 주시기 바랍니다.

### **존재하는 카드 & 현재 결제가 가능한 카드인지 체크하는 방법**

- 결제 가능 체크를 위해서는 실제로 결제하여 카드사 응답을 받아 이용 가능한 카드 여부 체크가 가능합니다.
- 등록 시점에 테스트 결제 1,000원을 해보고 곧바로 취소 성공하는 행위가 미래 시점에도 문제없이 결제가 될 것이라는 보장을 할 수는 없으나, 그 기능 자체만으로도 악성 사용자는 일부 필터링이 가능할 것으로 보입니다.

### **카드번호가 15자리일 경우**

- 고객 카드번호 등록 시 자릿수 제한 없이 포트원에서 정규화 과정을 거치므로 포맷과 무관하게 카드번호만 잘 전달되면 됩니다.

<Indent level="1">

- ex : 1234-1234-1234-123 또는 12341234.1234.123 등 모두 가능

</Indent>

### **카드 실 소유주 체크방법**

- 정기결제 등록은 카드번호 + 유효기간 + 생년월일 + 비밀번호 2자리만 알면 되다 보니 타인의 카드를 등록하는 것이 기술적으로 가능합니다.
- 따라서, 카드 실 소유주 즉 본인 카드로 만 제한하기 위해서는 본인인증 서비스와 연계하여 활용할 수 있습니다.
  '휴대폰 본인인증’과 ‘통합 본인인증’ 서비스를 활용해 다음과 같이 처리해 주셔야 합니다.

<Indent level="1">

**\[처리방법]**

1\. '휴대폰 본인인증’ 또는 ‘통합본인인증’ 먼저 진행

2\. 본인인증 후 수신되는 결괏값 중 생년월일을 고객사 내부에 저장 (타사 서비스 이용 시에는 타사 서비스를 통한 본인인증 응답 값 활용)

3\. 빌링키 등록을 위해 카드번호 + 유효기간 + 생년월일 + 비밀번호 2자리를 전달할 때 생년월일 값은 본인인증된 결값으로 고정하여 전달 (즉 사용자로부터 입력받지 않음)

</Indent>

<Callout content="1. 위 방법은 이론적으로는 생년월일까지 동일한(ex. 쌍둥이끼리) 타인의 카드를 등록할 수 있으나 매우 확률이 떨어지게 되므로 부정적인 사용의 관점에서의 기본적인 도용은 방지할 수 있습니다.

2. 포트원에서 휴대폰 본인인증은 다날을 통하여, 통합 본인인증은 KG 이니시스를 통하여 이용하실 수 있습니다." title="참고사항" icon="💡" />
